==> xmonad-0.12-2-armv7h.pkg.tar.xz: usr/share/haskell/xmonad/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.12
id: xmonad-0.12-8d8504347fd92509f5497e07981c17b8
key: xmona_34qYxK3mmQD5G5T8WBmVbC
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
exposed-modules:
    XMonad XMonad.Main XMonad.Core XMonad.Config XMonad.Layout
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-0.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-0.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/xmonad-0.12
hs-libraries: HSxmonad-0.12-34qYxK3mmQD5G5T8WBmVbC
depends:
    X11-1.6.1.2-4670912ab0053621e433826e2cb4ea46
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    setlocale-1.0.0.3-07fca6afc3ccd3cb91d350efd872e1ec
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.12-3-armv7h.pkg.tar.xz: usr/share/haskell/xmonad/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.12
id: xmonad-0.12-1b489d5bde9ffbcde54a74a6f033bf73
key: xmona_3lSxFDIBcp9Ea2WBzHc2D1
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
exposed-modules:
    XMonad XMonad.Main XMonad.Core XMonad.Config XMonad.Layout
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-0.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-0.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/xmonad-0.12
hs-libraries: HSxmonad-0.12-3lSxFDIBcp9Ea2WBzHc2D1
depends:
    X11-1.6.1.2-e77778265c7135c63ab82aead415c843
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    setlocale-1.0.0.3-07fca6afc3ccd3cb91d350efd872e1ec
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
